@@ -10,8 +10,7 @@
 %               M   M   OOO   N   N  IIIII    T     OOO   R  R                %
 %                                                                             %
 %                                                                             %
-%                    ImageMagick Progress Monitor Routines                    %
-%                                                                             %
+%                    ImageMagick Progress Monitor Methods                     %
 %                                                                             %
 %                                                                             %
 %                              Software Design                                %
@@ -19,26 +18,31 @@
 %                               December 1995                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1997 E. I. du Pont de Nemours and Company                        %
+%  Copyright (C) 2002 ImageMagick Studio, a non-profit organization dedicated %
+%  to making software imaging solutions freely available.                     %
 %                                                                             %
-%  Permission to use, copy, modify, distribute, and sell this software and    %
-%  its documentation for any purpose is hereby granted without fee,           %
-%  provided that the above Copyright notice appear in all copies and that     %
-%  both that Copyright notice and this permission notice appear in            %
-%  supporting documentation, and that the name of E. I. du Pont de Nemours    %
-%  and Company not be used in advertising or publicity pertaining to          %
-%  distribution of the software without specific, written prior               %
-%  permission.  E. I. du Pont de Nemours and Company makes no representations %
-%  about the suitability of this software for any purpose.  It is provided    %
-%  "as is" without express or implied warranty.                               %
+%  Permission is hereby granted, free of charge, to any person obtaining a    %
+%  copy of this software and associated documentation files ("ImageMagick"),  %
+%  to deal in ImageMagick without restriction, including without limitation   %
+%  the rights to use, copy, modify, merge, publish, distribute, sublicense,   %
+%  and/or sell copies of ImageMagick, and to permit persons to whom the       %
+%  ImageMagick is furnished to do so, subject to the following conditions:    %
 %                                                                             %
-%  E. I. du Pont de Nemours and Company disclaims all warranties with regard  %
-%  to this software, including all implied warranties of merchantability      %
-%  and fitness, in no event shall E. I. du Pont de Nemours and Company be     %
-%  liable for any special, indirect or consequential damages or any           %
-%  damages whatsoever resulting from loss of use, data or profits, whether    %
-%  in an action of contract, negligence or other tortious action, arising     %
-%  out of or in connection with the use or performance of this software.      %
+%  The above copyright notice and this permission notice shall be included in %
+%  all copies or substantial portions of ImageMagick.                         %
+%                                                                             %
+%  The software is provided "as is", without warranty of any kind, express or %
+%  implied, including but not limited to the warranties of merchantability,   %
+%  fitness for a particular purpose and noninfringement.  In no event shall   %
+%  ImageMagick Studio be liable for any claim, damages or other liability,    %
+%  whether in an action of contract, tort or otherwise, arising from, out of  %
+%  or in connection with ImageMagick or the use or other dealings in          %
+%  ImageMagick.                                                               %
+%                                                                             %
+%  Except as contained in this notice, the name of the ImageMagick Studio     %
+%  shall not be used in advertising or otherwise to promote the sale, use or  %
+%  other dealings in ImageMagick without prior written authorization from the %
+%  ImageMagick Studio.                                                        %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
@@ -50,7 +54,7 @@
   Include declarations.
 */
 #include "magick.h"
-
+#include "define.h"
 
 /*
   Global declarations.
@@ -63,46 +67,33 @@ static MonitorHandler
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   P r o g r e s s M o n i t o r                                             %
+%   M a g i c k M o n i t o r                                                 %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Function ProgressMonitor calls the monitor handler routines with a text
-%  string that describes the task and a measure of completion.
+%  MagickMonitor() calls the monitor handler method with a text string that
+%  describes the task and a measure of completion.
 %
-%  The format of the Monitor routine is:
+%  The format of the MagickMonitor method is:
 %
-%      ProgressMonitor(text,quantum,span)
+%      void MagickMonitor(const char *text,const off_t quantum,const off_t span)
 %
 %  A description of each parameter follows:
 %
-%    o quantum: Specifies the quantum position within the span which represents
-%      how much progress has been made in completing a task.
+%    o quantum: The position relative to the span parameter which represents
+%      how much progress has been made toward completing a task.
 %
-%    o span: Specifies the span relative to completing a task.
+%    o span: The span relative to completing a task.
 %
 %
 */
-Export void ProgressMonitor(char *text,const unsigned int quantum,
-  const unsigned int span)
+MagickExport void MagickMonitor(const char *text,const off_t quantum,
+  const off_t span)
 {
-#if defined(macintosh)
-  static char
-    *mark = (char *) NULL;
-
-  EventRecord
-    event;
-
-  while (WaitNextEvent(everyEvent,&event,0L,nil))
-    SIOUXHandleOneEvent(&event);
-  if (isatty(STDIN_FILENO) && (text != mark))
-    {
-      puts(text);
-      mark=text;
-    }
-#endif
+  assert(text != (const char *) NULL);
+  ProcessPendingEvents(text);
   if (monitor_handler != (MonitorHandler) NULL)
     (*monitor_handler)(text,quantum,span);
 }
@@ -118,20 +109,20 @@ Export void ProgressMonitor(char *text,const unsigned int quantum,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Function SetMonitorHandler sets the monitor handler to the specified routine
+%  SetMonitorHandler() sets the monitor handler to the specified method
 %  and returns the previous monitor handler.
 %
-%  The format of the SetMonitorHandler routine is:
+%  The format of the SetMonitorHandler method is:
 %
-%      previous_handler=SetMonitorHandler(handler)
+%      MonitorHandler SetMonitorHandler(MonitorHandler handler)
 %
 %  A description of each parameter follows:
 %
-%    o handler: Specifies a pointer to a routine to handle monitors.
+%    o handler: Specifies a pointer to a method to handle monitors.
 %
 %
 */
-Export MonitorHandler SetMonitorHandler(MonitorHandler handler)
+MagickExport MonitorHandler SetMonitorHandler(MonitorHandler handler)
 {
   MonitorHandler
     previous_handler;
